.. _complete_reference_api:

****************************************
Comprehensive Cosmo Utils Reference/API
****************************************

.. automodapi:: cosmo_utils.utils

.. automodapi:: cosmo_utils.utils.file_readers

.. automodapi:: cosmo_utils.utils.file_utils

.. automodapi:: cosmo_utils.utils.stats_funcs

.. automodapi:: cosmo_utils.utils.work_paths

.. automodapi:: cosmo_utils.utils.geometry

.. automodapi:: cosmo_utils.custom_exceptions

.. automodapi:: cosmo_utils.mock_catalogues

.. automodapi:: cosmo_utils.mock_catalogues.mags_calculations

.. automodapi:: cosmo_utils.mock_catalogues.spherematch

.. automodapi:: cosmo_utils.mock_catalogues.abundance_matching

.. automodapi:: cosmo_utils.mock_catalogues.catls_utils

.. automodapi:: cosmo_utils.mock_catalogues.pair_counters

.. automodapi:: cosmo_utils.mock_catalogues.shmr_funcs

.. automodapi:: cosmo_utils.ml

.. automodapi:: cosmo_utils.ml.ml_utils
